Plot hierarchical moving-window statistical analysis for time series.
Source:R/TH_plott.R
TH_plott.RdPlots hierarchical moving-window statistical analysis for custom functions.
The input is a data.frame created by TH_tweak() function.
Arguments
- results
is a
data.framecreated by TH_tweak().- scale
a
numeric, scaling factor for point sizes, autoset by default.- output_file
is a
string, optional, filename to save plot (NULL to skip saving).- colorscales
a
listof color scales for each function (optional). Can mix predefined names ("avg", "trend", "pval") and custom color vectors.- colorlimits
a
listof numeric vectors specifying color limits for each function (optional). Each element should be a vector of length 2 (c(min, max)). If NULL, limits are calculated automatically.
Author
Vladimiro Andrea Boselli, (2025) boselli.v@irea.cnr.it